﻿using System;
using System.Collections.Generic;
using DevExpress.Data.Filtering;
using DevExpress.Xpo.DB;
using Solution5.Module.BusinessObjects;

namespace Solution5.Module
{

	public class GetCategoryCodesTreeListNodeFunction : ICustomFunctionOperatorFormattable
	{
		public string FunctionName = "GetCategoryCodesTreeListNode";
		#region ICustomFunctionOperatorFormattable Members
		// The function's expression to be evaluated on the server. 
		string ICustomFunctionOperatorFormattable.Format(Type providerType, params string[] operands)
		{
			// This example implements the function for MS Access databases only. 
			if (providerType == typeof(AccessConnectionProvider))
				return string.Format("datepart(\"m\", {0})", operands[0]);
			throw new NotSupportedException(string.Concat(
				"This provider is not supported: ", providerType.Name));
		}

		public static string GetCategoryCodeTreeListNode(Category category)
		{
			List<string> categoryCodes = _recurcive(category);

			return String.Join(" , " ,categoryCodes);
		}

		private static  List<string> _recurcive( Category category)
		{
			List<string> categoryCodes = new List<string>();
			categoryCodes.Add(category.CategoryCode);

			if (category.NestedCategorys != null && category.NestedCategorys.Count > 0)
				foreach (var categoryChild in category.NestedCategorys)
				{
					categoryCodes.AddRange(_recurcive (categoryChild));
				}
			return categoryCodes;
		}
		#endregion

		#region ICustomFunctionOperator Members
		// Evaluates the function on the client. 
		object ICustomFunctionOperator.Evaluate(params object[] operands)
		{
			return GetCategoryCodeTreeListNode((Category)operands[0]);
		}

		string ICustomFunctionOperator.Name
		{
			get { return FunctionName; }
		}

		Type ICustomFunctionOperator.ResultType(params Type[] operands)
		{
			return typeof(string);
		}
		#endregion
	}

}
